@@ -941,7 +941,7 @@ class TestTestCli:
             boot_args=None,
             wait_for=None,
             callback=None,
-            command=[],
+            commands=[],
             qemu_image=None,
             tuxbuild=None,
         )
@@ -980,7 +980,7 @@ class TestTestCli:
             boot_args=None,
             wait_for=None,
             callback=None,
-            command=[],
+            commands=[],
             qemu_image=None,
             tuxbuild=None,
         )
@@ -1018,7 +1018,7 @@ class TestTestCli:
             boot_args=None,
             wait_for="mybuilduid",
             callback=None,
-            command=[],
+            commands=[],
             qemu_image=None,
             tuxbuild=None,
         )
@@ -1056,7 +1056,7 @@ class TestTestCli:
             boot_args=None,
             wait_for=None,
             callback=None,
-            command=[],
+            commands=[],
             qemu_image=None,
             tuxbuild=None,
         )
@@ -1102,7 +1102,7 @@ class TestTestCli:
             boot_args=None,
             wait_for=None,
             callback=None,
-            command=[],
+            commands=[],
             qemu_image=None,
             tuxbuild=None,
         )
