@@ -579,7 +579,7 @@ class Plan(HeadersMixin):
                             timeouts=test.get("timeouts"),
                             callback=test.get("callback"),
                             wait_for=build.uid,
-                            command=test.get("commands", []),
+                            commands=test.get("commands", []),
                             qemu_image=test.get("qemu_image"),
                             tuxbuild=test.get("tuxbuild"),
                         )
@@ -611,7 +611,7 @@ class Plan(HeadersMixin):
                             tests=test.get("tests", []),
                             timeouts=test.get("timeouts"),
                             callback=test.get("callback"),
-                            command=test.get("commands", []),
+                            commands=test.get("commands", []),
                             qemu_image=test.get("qemu_image"),
                             tuxbuild=test.get("tuxbuild"),
                         )
@@ -903,7 +903,7 @@ class Test(HeadersMixin):
     tests = attrib(default=[])
     timeouts = attrib(default=[])
     callback = attrib(default=None)
-    command = attrib(default=[])
+    commands = attrib(default=[])
     qemu_image = attrib(default=None)
     tuxbuild = attrib(default=None)
 
@@ -946,8 +946,8 @@ class Test(HeadersMixin):
             data["waiting_for"] = self.wait_for
         if self.callback:
             data["callback"] = self.callback
-        if self.command:
-            data["command"] = self.command
+        if self.commands:
+            data["commands"] = self.commands
         if self.qemu_image:
             data["qemu_image"] = self.qemu_image
         if self.tuxbuild:
