@@ -315,7 +315,7 @@ def handle_submit(cmdargs, _, config):
             timeouts=timeouts_d,
             wait_for=cmdargs.wait_for,
             callback=cmdargs.callback,
-            command=cmdargs.commands,
+            commands=cmdargs.commands,
             qemu_image=cmdargs.qemu_image,
             tuxbuild=cmdargs.tuxbuild,
         )
